pub fn circles_from_placed_containers(
containers: &[PlacedContainerView],
) -> Vec<NavBlockingCircle>Expand description
Blocking circles for placed props that have blocking on the item template (AOI view).
pub fn circles_from_placed_containers(
containers: &[PlacedContainerView],
) -> Vec<NavBlockingCircle>Blocking circles for placed props that have blocking on the item template (AOI view).